@@ -47,6 +47,7 @@ import board
 import analogio
 import digitalio
 import audioio
+import neopixel
 from gamepadshift import GamePadShift
 import adafruit_lis3dh
 from adafruit_pybadger.pybadger_base import PyBadgerBase
@@ -76,6 +77,11 @@ class PyGamer(PyBadgerBase):
         except ValueError:
             self._accelerometer = adafruit_lis3dh.LIS3DH_I2C(i2c, int1=int1)
 
+        # NeoPixels
+        self._neopixels = neopixel.NeoPixel(
+            board.NEOPIXEL, self._neopixel_count, brightness=1, pixel_order=neopixel.GRB
+        )
+
         self._buttons = GamePadShift(
             digitalio.DigitalInOut(board.BUTTON_CLOCK),
             digitalio.DigitalInOut(board.BUTTON_OUT),
